@@ -52,14 +52,17 @@ module Graphics.UI.GLUT.Initialization (
 import Control.Monad
 import Data.Bits
 import Data.List
-import Data.StateVar
 import Foreign.C.String
 import Foreign.C.Types
 import Foreign.Marshal.Array
 import Foreign.Marshal.Utils
 import Foreign.Ptr
 import Foreign.Storable
-import Graphics.Rendering.OpenGL ( Position(..), Size(..) )
+import Graphics.Rendering.OpenGL ( Position(..), Size(..)
+                                 , StateVar, GettableStateVar, get
+                                 , SettableStateVar, makeStateVar, ($=)
+                                 , makeGettableStateVar
+                                 , makeSettableStateVar )
 import Graphics.UI.GLUT.QueryUtils
 import Graphics.UI.GLUT.Raw
 import Graphics.UI.GLUT.Types
@@ -146,7 +149,7 @@ exit = glutExit
 -- | Controls the /initial window position/.  Windows created by
 -- 'Graphics.UI.GLUT.Window.createWindow' will be requested to be created with
 -- the current /initial window position/. The initial value of the /initial
--- window position/ GLUT state is @'Size' (-1) (-1)@. If either the X or Y
+-- window position/ GLUT state is @'Position' (-1) (-1)@. If either the X or Y
 -- component of the /initial window position/ is negative, the actual window
 -- position is left to the window system to determine.
 --
